<?php
session_start();


if (isset($_POST['remove_item']) && isset($_POST['item_index'])) {
    $itemIndex = $_POST['item_index'];
    if (isset($_SESSION['cart'][$itemIndex])) {
        unset($_SESSION['cart'][$itemIndex]);
    }
}

if (isset($_POST['clear_cart'])) {
    $_SESSION['cart'] = [];
}

function updateQuantity($itemIndex, $quantity) {
    if (isset($_SESSION['cart'][$itemIndex])) {
        $_SESSION['cart'][$itemIndex]['quantity'] = $quantity;
        if ($quantity <= 0) {
            unset($_SESSION['cart'][$itemIndex]);
        }
    }
}

if (isset($_POST['decrease_quantity']) && isset($_POST['item_index'])) {
    $itemIndex = $_POST['item_index'];
    updateQuantity($itemIndex, $_SESSION['cart'][$itemIndex]['quantity'] - 1);
}

if (isset($_POST['increase_quantity']) && isset($_POST['item_index'])) {
    $itemIndex = $_POST['item_index'];
    updateQuantity($itemIndex, $_SESSION['cart'][$itemIndex]['quantity'] + 1);
}


$cartCount = isset($_SESSION['cart']) ? count($_SESSION['cart']) : 0;
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <script src="https://cdn.tailwindcss.com"></script>
    <script src="https://kit.fontawesome.com/f6777e9957.js" crossorigin="anonymous"></script>
    <title>Shopping Cart</title>
</head>
<body>
    <header class="fixed top-0 left-0 z-20 w-full border-b border-gray-200 bg-white py-2.5 sm:px-4">
            <div class="flex flex-wrap items-center justify-between">
                <div class="my-4">
                    <a href="/store" class="self-center whitespace-nowrap font-semibold text-xl">STORE</a>
                </div>
                <div class="relative py-2 mr-6">
                    <a href="/store/cart.php">
                        <div class="t-0 absolute left-3 bottom-6">
                            <span class="flex h-2 w-2 items-center justify-center rounded-full bg-red-500 p-3 text-xs text-white"><?= $cartCount; ?></span>
                        </div>
                        <i class="fa-solid fa-cart-shopping text-[20px]"></i>
                    </a>
                </div>
            </div>
        </header>
        <section class="pt-28 pb-10 min-h-screen px-6 sm:px-4">
            <div class="mx-auto max-w-6xl">
                <div class="flex items-center text-sm font-normal uppercase gap-x-2 mt-4">
                    <h3 class="flex-[3]">Product</h3>
                    <h3 class="flex-1 text-left">Price</h3>
                    <h3 class="flex-1 text-center">Quantity</h3>
                    <h3 class="flex-1 text-right">Total</h3>
                </div>
                <?php
                if (isset($_SESSION['cart']) && is_array($_SESSION['cart'])) {
                    $subtotal = 0;

                    foreach ($_SESSION['cart'] as $itemIndex => $item) {

                        $quantity = isset($item['quantity']) ? $item['quantity'] : 1;
                        $item['total'] = $quantity * (float)$item['price'];
                        $subtotal += $item['total'];

                        if (is_array($item) && isset($item['img']) && isset($item['name']) && isset($item['price'])) {
                            ?>
                            <div class="border-t border-gray-200 py-4 flex items-center">
                                <div class="flex max-sm:flex-col max-sm:items-start flex-[3] items-center">
                                    <img src="<?= $item['img'] ?>" alt="<?= $item['name'] ?>" class="w-24 max-w-full mr-4 max-sm:mr-0">
                                    <div>
                                        <h2 class="font-bold"><?= $item['name'] ?></h2>
                                        <form method='POST' action=''>
                                            <input type='hidden' name='item_index' value='<?= $itemIndex ?>' />
                                            <button type='submit' name='remove_item' class='mt-2 text-rose-500 hover:text-rose-700'>Remove</button>
                                        </form>
                                    </div>
                                </div>
                                <div class="flex-1 text-sm font-normal">
                                    <?= $item['price'] ?>
                                </div>
                                <div class="flex flex-1 items-start justify-center border border-gray-200 rounded">
                                    <form method='POST' action=''>
                                        <input type='hidden' name='item_index' value='<?= $itemIndex ?>' />
                                        <button type='submit' name='decrease_quantity' class='hover:text-red-400 p-2'>-</button>
                                    </form>
                                    <div class="p-2"><?= $quantity ?></div>
                                    <form method='POST' action=''>
                                        <input type='hidden' name='item_index' value='<?= $itemIndex ?>' />
                                        <button type='submit' name='increase_quantity' class='hover:text-red-500 p-2'>+</button>
                                    </form>
                                </div>
                                <div class="text-sm font-bold text-right pr-2 flex-1"><?= number_format($item['total'], 2) ?>$</div>
                            </div>
                            <?php
                            } else {
                                echo "<p>Invalid item structure: ";
                            }
                        }
                    } else {
                        echo "<p>Your cart is empty!</p>";
                    }
                    ?>
                <div class="flex max-sm:flex-col justify-between items-start border-t border-gray-200 pt-8">
                    <form method="POST" action="">
                        <button type="submit" name="clear_cart" class="w-32 h-10 rounded border border-gray-200 font--normal tracking-wider text-gray-500 hover:text-rose-400 hover:border-rose-300 max-sm:order-last max-sm:mt-4">Clear Cart</button>
                    </form>
                    <div class="w-64 max-w-full max-sm:w-full">
                        <div class="flex justify-between text-lg">
                            <span>Subtotal</span>
                            <span><?= number_format($subtotal, 2) ?>$</span>
                        </div>
                        <p class="text-sm font-light my-2">Taxes and shipping calculated at checkout</p>
                        <form method="POST" action="">
                            <button type="submit" class="w-full h-10 rounded bg-rose-500 text-white hover:bg-rose-400">Checkout</button>
                        </form>
                        <div class="mt-4">
                            <a class="text-gray-500 flex items-center hover:text-rose-500" href="/store/index.php">
                                <span class="mr-2">Continue Shopping</span>
                                <i class="fa fa-arrow-right"></i>
                            </a>
                        </div>
                    </div>
                </div>
            </div>
        </section>

</body>
</html>
